Package: BradleyTerry2
Title: Bradley-Terry Models
Version: 1.1.3
Authors@R: c(
    person("Heather", "Turner", , "ht@heatherturner.net", role = c("aut", "cre")),
    person("David", "Firth", role = "aut")
  )
Description: Specify and fit the Bradley-Terry model, including structured
    versions in which the parameters are related to explanatory variables
    through a linear predictor and versions with contest-specific effects,
    such as a home advantage.
License: GPL (>= 2)
URL: https://github.com/hturner/BradleyTerry2
BugReports: https://github.com/hturner/BradleyTerry2/issues
Depends: R (>= 2.10)
Imports: brglm, gtools, lme4 (>= 1.0), qvcalc, stats
Suggests: bookdown, knitr, litedown, prefmod, testthat
Enhances: gnm
VignetteBuilder: knitr, litedown
Encoding: UTF-8
Language: en-GB
LazyData: yes
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-04-10 10:20:56 UTC; stspao
Author: Heather Turner [aut, cre],
  David Firth [aut]
Maintainer: Heather Turner <ht@heatherturner.net>
Repository: CRAN
Date/Publication: 2025-04-10 19:20:44 UTC
Built: R 4.3.3; ; 2025-04-10 21:55:07 UTC; unix
