# Generated by roxygen2: do not edit by hand

S3method(add1,BTm)
S3method(anova,BTm)
S3method(coef,BTabilities)
S3method(drop1,BTm)
S3method(formula,BTm)
S3method(model.matrix,BTm)
S3method(predict,BTglmmPQL)
S3method(predict,BTm)
S3method(print,BTabilities)
S3method(print,BTglmmPQL)
S3method(print,BTm)
S3method(print,summary.BTglmmPQL)
S3method(qvcalc,BTabilities)
S3method(residuals,BTm)
S3method(summary,BTglmmPQL)
S3method(vcov,BTabilities)
S3method(vcov,BTglmmPQL)
export(BTabilities)
export(BTm)
export(GenDavidson)
export(countsToBinomial)
export(glmmPQL)
export(glmmPQL.control)
export(plotProportions)
export(qvcalc)
importFrom(brglm,brglm)
importFrom(graphics,curve)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(gtools,combinations)
importFrom(lme4,findbars)
importFrom(lme4,nobars)
importFrom(qvcalc,qvcalc)
importFrom(qvcalc,qvcalc.default)
importFrom(stats,.checkMFClasses)
importFrom(stats,.getXlevels)
importFrom(stats,C)
importFrom(stats,add.scope)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,contrasts)
importFrom(stats,delete.response)
importFrom(stats,drop.scope)
importFrom(stats,family)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,gaussian)
importFrom(stats,glm.control)
importFrom(stats,glm.fit)
importFrom(stats,is.empty.model)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.offset)
importFrom(stats,model.response)
importFrom(stats,model.weights)
importFrom(stats,na.exclude)
importFrom(stats,na.omit)
importFrom(stats,na.pass)
importFrom(stats,napredict)
importFrom(stats,naprint)
importFrom(stats,optimize)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,plogis)
importFrom(stats,pnorm)
importFrom(stats,printCoefmat)
importFrom(stats,reformulate)
importFrom(stats,relevel)
importFrom(stats,runif)
importFrom(stats,symnum)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(stats,update.formula)
importFrom(stats,vcov)
importFrom(utils,flush.console)
