
<!-- README.md is generated from README.Rmd. Please edit that file -->

# BradleyTerry2

[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/BradleyTerry2)](https://cran.r-project.org/package=BradleyTerry2)

Specify and fit the Bradley-Terry model, including structured versions
in which the parameters are related to explanatory variables through a
linear predictor and versions with contest-specific effects, such as a
home advantage.

## Installation

You can install **BradleyTerry2** from github with:

``` r
# install.packages("devtools")
devtools::install_github("hturner/BradleyTerry2")
```

## Code of conduct

Please note that this project is released with a [Contributor Code of
Conduct](https://github.com/hturner/BradleyTerry2/blob/master/CONDUCT.md).
By participating in this project you agree to abide by its terms.
